@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2001-2008
+ * Copyright (c) 2001, 2008,
  *     DecisionSoft Limited. All rights reserved.
- * Copyright (c) 2004-2008
- *     Oracle. All rights reserved.
+ * Copyright (c) 2004, 2011,
+ *     Oracle and/or its affiliates. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,16 +15,8 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
- * $Id$
  */
 
-/*
-
-   Last function
-
-*/
-
 #ifndef _FUNCTIONLAST_HPP
 #define _FUNCTIONLAST_HPP
 
@@ -32,7 +24,6 @@
 
 #include <xqilla/ast/XQFunction.hpp>
 
-/** Last function*/
 class XQILLA_API FunctionLast : public XQFunction
 {
 public:
@@ -42,15 +33,12 @@ public:
 
   FunctionLast(const VectorOfASTNodes &args, XPath2MemoryManager* memMgr);
   
-  virtual ASTNode* staticResolution(StaticContext *context);
   virtual ASTNode *staticTypingImpl(StaticContext *context);
 
-  /** returns the context size */
   Sequence createSequence(DynamicContext* context, int flags=0) const;
 };
 
-#endif // _FUNCTIONLAST_HPP
-
+#endif
 
 
 
